@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '1.4.5'
+__version__ = '1.4.8'
 
 from .app import Kola
 from .blueprint import Blueprint
 from .utils import safe_call
-from .vals import logger
+from .log import logger
