@@ -2,8 +2,6 @@
 
 from .callbacks_mixin import AppCallBacksMixin
 from .connection import Connection
-from .utils import safe_call
-from .vals import logger
 
 
 class Kola(AppCallBacksMixin):
