@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from .vals import logger
+from .log import logger
 
 
 def safe_call(func, *args, **kwargs):
@@ -11,3 +11,5 @@ def safe_call(func, *args, **kwargs):
         return func(*args, **kwargs)
     except Exception, e:
         logger.exception('func raise exception. func: %s', func)
+        # 调用方可以通过 isinstance(e, BaseException) 来判断是否发生了异常
+        return e
